[−][src]Crate tokenizations
Tokenizations alignment functions.
Functions
| get_alignments | Returns the tokenizations alignments |
| get_charmap | Returns the character mappings |
| get_original_spans | Returns the span indices in original_text from the tokens based on the shortest edit script (SES). This is useful, for example, when a processed result is mapped to the original text that is not normalized yet. |
Type Definitions
| Alignment | |
| CharMap |